// Copyright (c) 2006-2007 nudge:nudge
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#import <Cocoa/Cocoa.h>


/** Posted when one of the receiver's bundles did update. The userInfo dictionary
	contains the corresponding bundle. */
extern NSString * const NNQueryBundleDidUpdate;


@interface NNQueryBundle : NSObject {

	NSMutableArray			*results;
	NSString				*value;
	NSString				*bundlingAttribute;
	
	NSMutableArray			*sortOrderArray;

}

/**
creates a new NNQueryBundle
 @returns new NNQueryBundle
 */
+ (NNQueryBundle *)bundle;

/**
 @param anItem PATaggableObject to add
*/
- (void)addObject:(id)anItem;

/**
 @param anItem PATaggableObject to look for
*/
- (BOOL)containsObject:(id)anItem;

/**
 @param anItem PATaggableObject to remove
 */
- (void)removeObject:(id)anItem;

/**
 @returns name of this bundle, e.g. "PDF"
*/
- (NSString *)stringValue;

/**
 @returns number of results
*/
- (unsigned)resultCount;

/**
 @param idx index of result to return
 @returns PATaggableObject at the given index
*/
- (id)resultAtIndex:(unsigned)idx;

/**
sorts the results of this bundle by the given selector
 @param comparator selector to use for sorting
*/
- (void)sortUsingSelector:(SEL)comparator;

/**
 @returns results of this bundle
*/
- (NSArray *)results;

/**
sets a new array for results
 @param newResults new results to use
*/
- (void)setResults:(NSArray *)newResults;

/**
 @returns value of this bundle, currently equal to stringValue, e.g. "PDF"
 */
- (NSString *)value;

/**
sets the value of this bundle
 @param newValue new value to use
*/
- (void)setValue:(NSString *)newValue;

/**
NOT IMPLEMENTED YET - bundling attribute to use for sub-bundling of results
 @returns bundling attribute of sub-bundles
*/
- (NSString *)bundlingAttribute;

/**
NOT IMPLEMENTED YET - new bundling attribute to use fo sub-bundling of results
 @param attribute new attribute to use for sub-bundling
*/
- (void)setBundlingAttribute:(NSString *)attribute;

@end
