// Copyright (c) 2006-2007 nudge:nudge
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#import <Cocoa/Cocoa.h>
#import "NNFile.h"
#import "NNTag.h"
#import "NNTags.h"
#import "NNQuery.h"
#import "NNSelectedTags.h"

/**
Finds related tags for a given query or a given selection of tags. Tags are related if they are on
 the same NNTaggableObject

 use this class if you want performance, it uses a query passed from the outside and observes its changes
  (i.e. from the browser)

 for a version with integrated query use NNRelatedTagsStandalone
 
 posts NNRelatedTagsHaveChanged notification on update
 */
@interface NNRelatedTags : NSObject {
	NNTags *tags;
	
	NSMutableArray *relatedTags;
	BOOL updating;

	NSNotificationCenter *nc;
	NNQuery *query;
	NNSelectedTags *selectedTags;
}

/**
initializes related tags with some selected tags and a query
 @param otherSelectedTags is needed because related tags cannot contains tags from selected tags
 @param aQuery the query passed from the outside is observed and related tags adjusted periodically
 */
- (id)initWithSelectedTags:(NNSelectedTags*)otherSelectedTags query:(NNQuery*)aQuery;

/**
 @returns array of NNTags related to selectedTags:
*/
- (NSMutableArray*)relatedTags;

/**
 @returns count of currently found related Tags
 */
- (unsigned)count;

/**
@returns the selected tags for which related tags are currently looked for
 */
- (NNSelectedTags*)selectedTags;

/**
set the tags for which you wish to find related tags
 @param otherTags selected tags to find tags for
 */
- (void)setSelectedTags:(NNSelectedTags*)otherTags;

/**
@returns YES if the related tags are currently updated; NO otherwise
 */
- (BOOL)isUpdating;

/**
@returns YES if aTag is currently part of related tags; NO otherwise
 */
- (BOOL)containsTag:(NNTag*)aTag;

/**
query to use for updating related tags
 @param aQuery NNQuery used to search for NNTaggableObjects
 */
- (void)setQuery:(NNQuery*)aQuery;

/**
empties related tags
 */
- (void)removeAllTags;

@end